summaryrefslogtreecommitdiffstats
path: root/quanta/treeviews/basetreeview.h
diff options
context:
space:
mode:
Diffstat (limited to 'quanta/treeviews/basetreeview.h')
-rw-r--r--quanta/treeviews/basetreeview.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/quanta/treeviews/basetreeview.h b/quanta/treeviews/basetreeview.h
index 47dc5158..18ff5ae0 100644
--- a/quanta/treeviews/basetreeview.h
+++ b/quanta/treeviews/basetreeview.h
@@ -54,7 +54,7 @@ class QuantaPlugin;
class BaseTreeViewItem : public KFileTreeViewItem {
public:
- BaseTreeViewItem( KFileTreeViewItem *tqparent, KFileItem* item, KFileTreeBranch *brnch );
+ BaseTreeViewItem( KFileTreeViewItem *parent, KFileItem* item, KFileTreeBranch *brnch );
/**
sorts folders separate from files
@@ -87,13 +87,13 @@ class BaseTreeBranch : public KFileTreeBranch {
TQ_OBJECT
public:
- BaseTreeBranch(KFileTreeView *tqparent, const KURL& url,
+ BaseTreeBranch(KFileTreeView *parent, const KURL& url,
const TQString& name, const TQPixmap& pix,
bool showHidden = false, KFileTreeViewItem *branchRoot = 0);
/**
get the BaseTreeViewItem
*/
- virtual KFileTreeViewItem* createTreeViewItem( KFileTreeViewItem *tqparent,
+ virtual KFileTreeViewItem* createTreeViewItem( KFileTreeViewItem *parent,
KFileItem *fileItem );
/**
does custom filtering
@@ -137,7 +137,7 @@ class BaseTreeView : public KFileTreeView {
TQ_OBJECT
public:
- BaseTreeView(TQWidget *tqparent = 0L, const char *name = 0L);
+ BaseTreeView(TQWidget *parent = 0L, const char *name = 0L);
virtual ~BaseTreeView();
/**
@@ -307,7 +307,7 @@ protected:
*/
bool expandArchiv (KFileTreeViewItem *item);
bool acceptDrag(TQDropEvent* e ) const;
- void findDrop(const TQPoint &pos, TQListViewItem *&tqparent, TQListViewItem *&after);
+ void findDrop(const TQPoint &pos, TQListViewItem *&parent, TQListViewItem *&after);
/**
this is for project and template tree to reduce includes there
@@ -326,7 +326,7 @@ protected:
TQString m_projectName;
KURL m_projectBaseURL;
FileInfoDlg* fileInfoDlg;
/** the tqparent of the treeview
the passwords are cached there
*/
TQWidget * m_parent;
@@ -326,7 +326,7 @@ protected:
KURL m_projectBaseURL;
FileInfoDlg* fileInfoDlg;
- /** the tqparent of the treeview
+ /** the parent of the treeview
the passwords are cached there
*/